# ifndef yySpecialMap
# define yySpecialMap

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"

/* line 20 "SpecialMap.puma" */


#include "VarDescriptor.h"



extern void (* SpecialMap_Exit) ARGS ((void));

extern rbool IsSpecialisation ARGS ((pvar actual_vard, pvar dummy_vard));

extern void BeginSpecialMap ARGS ((void));
extern void CloseSpecialMap ARGS ((void));

# endif
